@@ -1,7 +1,7 @@
 from json import JSONDecodeError
-import os
 import click
 from pydantic.error_wrappers import ValidationError
+import importlib.metadata
 
 from .._utils import CustomClickException
 from ..._utils import init_shared_object, SharedObject, setup_app
@@ -9,9 +9,11 @@ from wton import settings
 from wton.config import Config, ConfigNotFoundError, WtonConfig, ProviderConfig
 from wton.utils import storage
 
+__version__ = importlib.metadata.version('wton')
+
 
 @click.group(context_settings=dict(help_option_names=['-h', '--help']))
-@click.version_option("0.0.7")
+@click.version_option(__version__)
 @click.option("-c", "--config", 'specific_config_path', metavar='', help="Use specific config.yaml file.")
 @click.pass_context
 def cli(ctx, specific_config_path: str):
