@@ -3,7 +3,7 @@ from collections import OrderedDict
 import inquirer
 from halo import Halo
 
-from .._utils import echo_error
+from .._utils import echo_error, echo_success
 from ..._utils import SharedObject
 from .._modified_inquirer import ModifiedConsoleRender, ModifiedTheme
 from .._exceptions import EscButtonPressed
@@ -15,7 +15,7 @@ class BaseSet(metaclass=ABCMeta):
     def __init__(self, ctx: SharedObject) -> None:
         self.ctx = ctx
         self._exit = False
-        self._spinner = Halo(text='Loading', spinner='dots')
+        self._spinner = Halo(text='Processing', spinner='dots')
 
     def show(self):
         while not self._exit:
@@ -35,6 +35,9 @@ class BaseSet(metaclass=ABCMeta):
             except EscButtonPressed as e:
                 pass
             except Exception as e:
+                if self.ctx.debug_mode:
+                    raise
+
                 echo_error(e)
 
     def _prompt(self, questions):
@@ -52,3 +55,12 @@ class BaseSet(metaclass=ABCMeta):
 
     def _stop_loading(self):
         self._spinner.stop()
+
+    def _parse_broadcast_result(self, result):
+        if "status" in result:
+            if result["status"] == 1:
+                echo_success("Transaction has been commited")
+            else:
+                echo_success("Transaction has been sent but hasn't been committed into blockchain during 20 seconds.")
+        else:
+            echo_error(result)
