@@ -27,7 +27,7 @@ class WhitelistSet(BaseSet):
     def _handle_list(self):
         questions = [
             inquirer.Confirm(
-                "verbose", message='Show verbose information?', default=True),
+                "verbose", message='Show balances?', default=True),
         ]
         verbose = self._prompt(questions)["verbose"]
 
